@@ -71,11 +71,6 @@ class _CD(BaseCommand):
 
     @staticmethod
     def add_arguments(parser):
-        # FIXME: have a cache of these pickles somewhere
-        parser.add_argument('-T', '--toc-pickle',
-                            action="store", dest="toc_pickle",
-                            help="pickle to use for reading and "
-                            "writing the TOC")
         parser.add_argument('-R', '--release-id',
                             action="store", dest="release_id",
                             help="MusicBrainz release id to match to "
@@ -103,9 +98,8 @@ class _CD(BaseCommand):
         utils.unmount_device(self.device)
 
         # first, read the normal TOC, which is fast
-        self.ittoc = self.program.getFastToc(self.runner,
-                                             self.options.toc_pickle,
-                                             self.device)
+        print("Reading TOC...")
+        self.ittoc = self.program.getFastToc(self.runner, self.device)
 
         # already show us some info based on this
         self.program.getRipResult(self.ittoc.getCDDBDiscId())
@@ -175,7 +169,7 @@ class _CD(BaseCommand):
             try:
                 self.program.result.cdparanoiaDefeatsCache = \
                     self.config.getDefeatsCache(*info)
-            except KeyError as e:
+            except KeyError, e:
                 logger.debug('Got key error: %r' % (e, ))
         self.program.result.artist = self.program.metadata \
             and self.program.metadata.artist \
@@ -415,7 +409,7 @@ Log files will log the path to tracks relative to this directory.
                                                   len(self.itable.tracks),
                                                   extra))
                         break
-                    except Exception as e:
+                    except Exception, e:
                         logger.debug('Got exception %r on try %d',
                                      e, tries)
 
